@@ -2,6 +2,7 @@ import click
 
 from mysocketctl.utils import *
 
+
 @click.group()
 def login():
     pass
@@ -25,11 +26,12 @@ def get_token(user_email, user_pass):
 
 @login.command()
 @click.option("--email", required=True, help="your email")
-@click.option("--password", required=True, help="your pasword")
+@click.password_option("--password", required=True, help="your pasword")
 def login(email, password):
     """Login to mysocket and get a token"""
     token = get_token(email, password)["token"]
     f = open(token_file, "w")
     f.write(token)
     f.close()
-    print("Logged in! Token stored in " + token_file + "\n")
+    os.chmod(token_file, 0o600)
+    print(f"Logged in! Token stored in {token_file}\n")
